==> mmoo_base_recharge-1.2.3.tar.gz: lib/card/ui/util/util.dart <==
import 'package:mmoo_base_recharge/card/ui/constants/constanst.dart';
import 'package:flutter/material.dart';

Size textSize(String text, TextStyle style) {
  final TextPainter textPainter = TextPainter(
      text: TextSpan(text: text, style: style),
      maxLines: 1,
      textDirection: TextDirection.ltr)
    ..layout(minWidth: 0, maxWidth: double.infinity);
  return textPainter.size;
}

final master = Image.asset('images/mastercard.png', width: 50);
final visa = Image.asset('images/visacard.png', width: 50);
final discover = Image.asset('images/discover.png', width: 50);

final amex = Image.asset('images/amex.png', width: 50);

final others = Container();

final Map<CardCompany, Set<List<String>>> cardNumPatterns =
    <CardCompany, Set<List<String>>>{
  CardCompany.VISA: <List<String>>{
    <String>['4'],
  },
  CardCompany.AMERICAN_EXPRESS: <List<String>>{
    <String>['34'],
    <String>['37'],
  },
  CardCompany.DISCOVER: <List<String>>{
    <String>['6011'],
    <String>['622126', '622925'],
    <String>['644', '649'],
    <String>['65']
  },
  CardCompany.MASTER: <List<String>>{
    <String>['51', '55'],
    <String>['2221', '2229'],
    <String>['223', '229'],
    <String>['23', '26'],
    <String>['270', '271'],
    <String>['2720'],
  },
};

CardCompany detectCardCompany(String cardNumber) {
  //Default card type is other
  CardCompany cardType = CardCompany.OTHER;

  if (cardNumber.isEmpty) {
    return cardType;
  }

  cardNumPatterns.forEach(
    (CardCompany type, Set<List<String>> patterns) {
      for (List<String> patternRange in patterns) {
        String ccPatternStr = cardNumber.replaceAll(RegExp(r'\s+\b|\b\s'), '');
        final int rangeLen = patternRange[0].length;
        if (rangeLen < cardNumber.length) {
          ccPatternStr = ccPatternStr.substring(0, rangeLen);
        }

        if (patternRange.length > 1) {
          final int ccPrefixAsInt = int.parse(ccPatternStr);
          final int startPatternPrefixAsInt = int.parse(patternRange[0]);
          final int endPatternPrefixAsInt = int.parse(patternRange[1]);
          if (ccPrefixAsInt >= startPatternPrefixAsInt &&
              ccPrefixAsInt <= endPatternPrefixAsInt) {
            cardType = type;
            break;
          }
        } else {
          if (ccPatternStr == patternRange[0]) {
            cardType = type;
            break;
          }
        }
      }
    },
  );

  return cardType;
}

==> mmoo_base_recharge-2.0.0.tar.gz: lib/card/ui/util/util.dart <==
import 'package:flutter/material.dart';
import 'package:mmoo_base/utils/common_utils.dart';
import 'package:mmoo_base_recharge/card/ui/constants/constanst.dart';
import 'package:mmoo_base_recharge/card/utils/recharge_constant.dart';

Size textSize(String text, TextStyle style) {
  final TextPainter textPainter = TextPainter(
      text: TextSpan(text: text, style: style),
      maxLines: 1,
      textDirection: TextDirection.ltr)
    ..layout(minWidth: 0, maxWidth: double.infinity);
  return textPainter.size;
}

final master = CommonUtils.getLoadWidget(
    RechargeConstantIcons.mastercard,
    "",
    RechargeConstantIcons.imagesUrl,
    RechargeConstantIcons.card_card,
    RechargeConstantColors.text_tip_color,
    RechargeConstantColors.app_color,
    width: 50,
    package: 'mmoo_base_recharge');
final visa = CommonUtils.getLoadWidget(
    RechargeConstantIcons.visacard,
    "",
    RechargeConstantIcons.imagesUrl,
    RechargeConstantIcons.card_card,
    RechargeConstantColors.text_tip_color,
    RechargeConstantColors.app_color,
    width: 50,
    package: 'mmoo_base_recharge');
final discover = CommonUtils.getLoadWidget(
    RechargeConstantIcons.discover,
    "",
    RechargeConstantIcons.imagesUrl,
    RechargeConstantIcons.card_card,
    RechargeConstantColors.text_tip_color,
    RechargeConstantColors.app_color,
    width: 50,
    package: 'mmoo_base_recharge');

final amex = CommonUtils.getLoadWidget(
    RechargeConstantIcons.amex,
    "",
    RechargeConstantIcons.imagesUrl,
    RechargeConstantIcons.card_card,
    RechargeConstantColors.text_tip_color,
    RechargeConstantColors.app_color,
    width: 50,
    package: 'mmoo_base_recharge');

final others = Container();

final Map<CardCompany, Set<List<String>>> cardNumPatterns =
    <CardCompany, Set<List<String>>>{
  CardCompany.VISA: <List<String>>{
    <String>['4'],
  },
  CardCompany.AMERICAN_EXPRESS: <List<String>>{
    <String>['34'],
    <String>['37'],
  },
  CardCompany.DISCOVER: <List<String>>{
    <String>['6011'],
    <String>['622126', '622925'],
    <String>['644', '649'],
    <String>['65']
  },
  CardCompany.MASTER: <List<String>>{
    <String>['51', '55'],
    <String>['2221', '2229'],
    <String>['223', '229'],
    <String>['23', '26'],
    <String>['270', '271'],
    <String>['2720'],
  },
};

CardCompany detectCardCompany(String cardNumber) {
  //Default card type is other
  CardCompany cardType = CardCompany.OTHER;

  if (cardNumber.isEmpty) {
    return cardType;
  }

  cardNumPatterns.forEach(
    (CardCompany type, Set<List<String>> patterns) {
      for (List<String> patternRange in patterns) {
        String ccPatternStr = cardNumber.replaceAll(RegExp(r'\s+\b|\b\s'), '');
        final int rangeLen = patternRange[0].length;
        if (rangeLen < cardNumber.length) {
          ccPatternStr = ccPatternStr.substring(0, rangeLen);
        }

        if (patternRange.length > 1) {
          final int ccPrefixAsInt = int.parse(ccPatternStr);
          final int startPatternPrefixAsInt = int.parse(patternRange[0]);
          final int endPatternPrefixAsInt = int.parse(patternRange[1]);
          if (ccPrefixAsInt >= startPatternPrefixAsInt &&
              ccPrefixAsInt <= endPatternPrefixAsInt) {
            cardType = type;
            break;
          }
        } else {
          if (ccPatternStr == patternRange[0]) {
            cardType = type;
            break;
          }
        }
      }
    },
  );

  return cardType;
}
